#include "tao/PortableServer/ORT_Adapter_Factory.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

namespace TAO
{
  ORT_Adapter_Factory::~ORT_Adapter_Factory ()
  {
  }
}

TAO_END_VERSIONED_NAMESPACE_DECL
